@@ -119,7 +119,7 @@ class Literal(Token):
             Log.error("Expecting string for literal")
         Token.__init__(self)
 
-        self.set_config(match=match)
+        self.set_config(match=match, regex=regex_compile(re.escape(match)))
 
         if len(match) == 0:
             Log.error("Literal must be at least one character")
@@ -143,7 +143,7 @@ class Literal(Token):
         return Literal(self.parser_config.match[::-1])
 
     def __regex__(self):
-        return "+", re.escape(self.parser_config.match)
+        return "+", self.parser_config.regex.pattern
 
     def __str__(self):
         return self.parser_config.match
@@ -169,9 +169,6 @@ class SingleCharLiteral(Literal):
     def reverse(self):
         return self
 
-    def __regex__(self):
-        return "*", re.escape(self.parser_config.match)
-
 
 class Keyword(Token):
     __slots__ = []
@@ -252,7 +249,8 @@ class CaselessLiteral(Literal):
     def __init__(self, match):
         Literal.__init__(self, match.upper())
         self.set_config(
-            match=match, regex=regex_compile(regex_caseless(match)),
+            match=match,
+            regex=regex_compile(regex_caseless(re.escape(match))),
         )
         self.parser_name = repr(self.parser_config.regex.pattern)
 
@@ -364,15 +362,17 @@ class Word(Token):
                 init_chars = init_chars.expecting().keys()
             prec, regexp = Char(init_chars, exclude=exclude)[min:max].__regex__()
         elif max is None or max == MAX_INT:
-            prec, regexp = (
-                Char(init_chars, exclude=exclude)
-                + Char(body_chars, exclude=exclude)[min - 1 :]
-            ).__regex__()
+            with whitespaces.NO_WHITESPACE:
+                prec, regexp = (
+                    Char(init_chars, exclude=exclude)
+                    + Char(body_chars, exclude=exclude)[min - 1 :]
+                ).__regex__()
         else:
-            prec, regexp = (
-                Char(init_chars, exclude=exclude)
-                + Char(body_chars, exclude=exclude)[min - 1 : max - 1]
-            ).__regex__()
+            with whitespaces.NO_WHITESPACE:
+                prec, regexp = (
+                    Char(init_chars, exclude=exclude)
+                    + Char(body_chars, exclude=exclude)[min - 1 : max - 1]
+                ).__regex__()
 
         if as_keyword:
             regexp = r"\b" + regexp + r"\b"
